@@ -94,15 +94,18 @@ class LearningMachine(object):
                dEstop=1.0,
                nn=True,vdwnn=False,
                bo_layer=[2,1],
-               bf_layer=[6,1],
+               mf_layer=[6,1],
                be_layer=[6,1],
                EnergyFunction=3,
                MessageFunction=1,
                bom={'others':1.0},
                bore={'others':0.45},
                weight={'others':2.0},
+               spv_bm=False,
+               spv_be=False,
                bo_penalty=10000.0,
                mefac=0.1,
+               writelib=5000,
                xcf='VDW',
                xca='DRSLL',
                basistype='DZP'):
@@ -154,15 +157,18 @@ class LearningMachine(object):
       self.nn           = nn
       self.vdwnn        = vdwnn
       self.bo_layer     = bo_layer
-      self.bf_layer     = bf_layer
+      self.mf_layer     = mf_layer
       self.be_layer     = be_layer
       self.bore         = bore
       self.bom          = bom
+      self.spv_bm       = spv_bm
+      self.spv_be       = spv_be
       self.mefac        = mefac
       self.weight       = weight
       self.bo_penalty   = bo_penalty
       self.EnergyFunction = EnergyFunction
       self.MessageFunction= MessageFunction
+      self.writelib     = writelib
       self.freeatoms    = FreeAtoms
       self.a            = AtomDance(poscar=self.initConfig,nn=self.nn,
                                     rmin=self.rmin-0.05,rmax=self.rmax,
@@ -316,18 +322,19 @@ class LearningMachine(object):
           while (accu<=self.accCriteria or loss>=self.lossCriteria) and training:        
                 self.load_config()
                 loss,accu,accMax,p,zpe,tstep = self.trainer(direcs=trajs_,
-                                                     step=self.step,
+                                                     step=self.step,writelib=self.writelib,
                                                      batch=self.batch,
                                                      convergence=self.accCriteria,
                                                      lossConvergence=self.lossCriteria,
                                                      nn=self.nn,vdwnn=self.vdwnn,
                                                      mpopt=self.mpopt,
                                                      bo_layer=self.bo_layer,
-                                                     bf_layer=self.bf_layer,
+                                                     mf_layer=self.mf_layer,
                                                      be_layer=self.be_layer,
                                                      EnergyFunction=self.EnergyFunction,
                                                      MessageFunction=self.MessageFunction,
                                                      bore=self.bore, bom=self.bom,
+                                                     spv_be=self.spv_be,spv_bm=self.spv_bm,
                                                      mefac=self.mefac,weight=self.weight,
                                                      bo_penalty=self.bo_penalty)
                 self.load_config()
@@ -517,7 +524,7 @@ class LearningMachine(object):
 
   def save_config(self):
       with open('options.json','w') as fj:
-           InPut = {'accCriteria':self.accCriteria,
+           options = {'accCriteria':self.accCriteria,
                     'lossCriteria':self.lossCriteria,
                     'lossTole':self.lossTole,
                     'rmax':self.rmax,
@@ -549,46 +556,48 @@ class LearningMachine(object):
                     'colFrame':self.colFrame,
                     'UseZmat':self.UseZmat,
                     'freeatoms':self.freeatoms,
-                    'bore':self.bore}
-           js.dump(InPut,fj,sort_keys=True,indent=2)
+                    'bore':self.bore,
+                    'writelib':self.writelib}
+           js.dump(options,fj,sort_keys=True,indent=2)
 
   def load_config(self):
       with open('options.json','r') as fj:
-           InPut = js.load(fj)
-           self.accCriteria  = InPut['accCriteria']
-           self.lossCriteria = InPut['lossCriteria']
-           self.lossTole     = InPut['lossTole']
-           self.rmax         = InPut['rmax']
-           self.angmax      = InPut['angmax']
-           self.accTole      = InPut['accTole']
-           self.accMax       = InPut['accMax']
-           self.accInc       = InPut['accInc']
-           self.resetAcc     = InPut['resetAcc']
-           self.step         = InPut['step'] 
-           self.dft_step     = InPut['dft_step'] 
-           self.md_step      = InPut['md_step'] 
-           self.mom_step     = InPut['mom_step'] 
-           self.MaxMDstep    = InPut['MaxMDstep'] 
-           self.EngTole      = InPut['EngTole'] 
-           self.dEtole       = InPut['dEtole'] 
-           self.d2Etole      = InPut['d2Etole'] 
-           self.dEstop       = InPut['dEstop'] 
-           self.mdInc        = InPut['mdInc'] 
-           self.dt_aimd      = InPut['dt_aimd'] 
-           self.dt_mlmd      = InPut['dt_mlmd'] 
-           self.rmin        = InPut['rmin'] 
-           self.Tmax         = InPut['Tmax'] 
-           self.T            = InPut['T'] 
-           self.maxiter      = InPut['maxiter']
-           self.max_batch    = InPut['max_batch']
-           self.mpopt        = InPut['mpopt']
-           self.mefac        = InPut['mefac']
-           self.learnWay     = InPut['learnWay']
-           self.colFrame     = InPut['colFrame']
-           self.UseZmat    = InPut['UseZmat']
-           self.bore         = InPut['bore']
-           if self.freeatoms!= InPut['freeatoms']:
-              self.freeatoms = InPut['freeatoms']
+           options = js.load(fj)
+           self.accCriteria  = options['accCriteria']
+           self.lossCriteria = options['lossCriteria']
+           self.lossTole     = options['lossTole']
+           self.rmax         = options['rmax']
+           self.angmax       = options['angmax']
+           self.accTole      = options['accTole']
+           self.accMax       = options['accMax']
+           self.accInc       = options['accInc']
+           self.resetAcc     = options['resetAcc']
+           self.step         = options['step'] 
+           self.dft_step     = options['dft_step'] 
+           self.md_step      = options['md_step'] 
+           self.mom_step     = options['mom_step'] 
+           self.MaxMDstep    = options['MaxMDstep'] 
+           self.EngTole      = options['EngTole'] 
+           self.dEtole       = options['dEtole'] 
+           self.d2Etole      = options['d2Etole'] 
+           self.dEstop       = options['dEstop'] 
+           self.mdInc        = options['mdInc'] 
+           self.dt_aimd      = options['dt_aimd'] 
+           self.dt_mlmd      = options['dt_mlmd'] 
+           self.rmin         = options['rmin'] 
+           self.Tmax         = options['Tmax'] 
+           self.T            = options['T'] 
+           self.maxiter      = options['maxiter']
+           self.max_batch    = options['max_batch']
+           self.mpopt        = options['mpopt']
+           self.mefac        = options['mefac']
+           self.learnWay     = options['learnWay']
+           self.colFrame     = options['colFrame']
+           self.UseZmat      = options['UseZmat']
+           self.bore         = options['bore']
+           self.writelib     = options['writelib']
+           if self.freeatoms!= options['freeatoms']:
+              self.freeatoms = options['freeatoms']
               self.a.get_freebond(self.freeatoms)
            
   def close(self):
@@ -601,42 +610,35 @@ if __name__ == '__main__':
    direcs = {'nm6_5':'/home/feng/siesta/nm6_5',
              'nm6_14':'/home/feng/siesta/nm6_14' }
 
-   lm = LearningMachine(direcs=direcs,
-                       ncpu=4,
-                       maxiter=200,
-                       dt_mlmd=0.1,
-                       dt_aimd=1.0,
-                       max_batch=20,
-                       dft_step=20,
-                       batch=50,
-                       step=20000,
-                       md_step=10,
-                       MaxMDstep=20,
-                       T=350,
-                       Tmax=500,
-                       convergence=0.0001,
-                       accCriteria=0.943,
-                       accMax=0.94,
-                       accMin=0.92,
-                       accInc=1.00002,
-                       resetAcc=2,
-                       mdInc=1.1,
-                       nn=True,
-                       mpopt=1,
-                       messages=1,
-                       learnWay=3,
-                       colFrame=10,
-                       rmin=0.6,
-                       EngTole=0.1,
-                       dEtole=0.20,
-                       d2Etole=0.05,
-                       dEstop=0.6,
-                       bo_layer=[4,1],
-                       bf_layer=[9,3],
-                       be_layer=[9,2],
-                       EnergyFunction=3,
-                       MessageFunction=1,
-                       FreeAtoms=None)
+   lm = LearningMachine(initConfig='noco6.gen',
+                        direcs=direcs,
+                        ncpu=4,
+                        maxiter=100,
+                        dt_mlmd=0.2,dt_aimd=1.0,dft_step=5,
+                        batch=50,max_batch=50,
+                        step=20000,md_step=50,mom_step=20,
+                        colFrame=25,
+                        MaxMDstep=100,
+                        T=800,Tmax=800,
+                        convergence=0.04,accCriteria=0.9,accMax=0.962,
+                        accTole=0.01,accInc=1.001,
+                        lossCriteria=26.0,lossTole=2.0,
+                        UseZmat=False,
+                        resetAcc=1,
+                        mdInc=1.1,
+                        nn=True,
+                        messages=1,
+                        mefac=0.005,
+                        learnWay=5,
+                        weight={'noco':2.0,'others':2.0},
+                        EngTole=0.085,dEtole=0.14,dEstop=1.0,d2Etole=0.06,
+                        rmin=0.7,rmax=1.3,angmax=30.0,
+                        bo_layer=[4,1],mf_layer=[6,2],be_layer=[3,1],
+                        EnergyFunction=3,MessageFunction=1,
+                        FreeAtoms=[2,3,12,13],
+                        writelib=5000,
+                        xcf='GGA',xca='PBE',basistype='split')
+   
    lm.run()
    lm.close()
 
