@@ -2,7 +2,7 @@ from __future__ import print_function
 from os import system,getcwd,chdir 
 from os.path import isfile,exists
 from ..molecule import enlarge,molecules,get_neighbors
-from .mdtodata import MDtoData
+from ..data.mdtodata import MDtoData
 from ase.io import read,write
 from ase.io.trajectory import TrajectoryWriter,Trajectory
 from ase.calculators.singlepoint import SinglePointCalculator
