@@ -46,7 +46,7 @@ class MPNN(ReaxFF):
                TwoBodyOnly=False,
                mpopt=None,
                bo_layer=[2,1],
-               bf_layer=[6,1],
+               mf_layer=[6,1],
                be_layer=[6,1],
                vdw_layer=[4,1],
                vdwnn=False,
@@ -55,6 +55,8 @@ class MPNN(ReaxFF):
                spec=[],
                sort=False,
                pkl=False,
+               spv_bm=False,
+               spv_be=False,
                bo_penalty=100000.0,
                optMethod='ADAM',
                maxstep=60000,
@@ -76,9 +78,11 @@ class MPNN(ReaxFF):
       self.EnergyFunction   = EnergyFunction
       self.MessageFunction  = MessageFunction
       self.bom              = bom
+      self.spv_be           = spv_be
+      self.spv_bm           = spv_bm
       self.TwoBodyOnly      = TwoBodyOnly
       # self.bo_layer       = bo_layer
-      self.bf_layer         = bf_layer
+      self.mf_layer         = mf_layer
       self.be_layer         = be_layer
       self.vdw_layer        = vdw_layer
       self.vdwnn            = vdwnn
@@ -111,7 +115,7 @@ class MPNN(ReaxFF):
   def supervise(self):
       ''' supervised learning term'''
       l_atol = 0.0
-      self.diffa,self.diffb,self.diffe,self.bosip = {},{},{},{}
+      self.diffa,self.diffb,self.diffe = {},{},{}
       for bd in self.bonds: 
           [atomi,atomj] = bd.split('-') 
           if self.nbd[bd]>0:
@@ -130,29 +134,34 @@ class MPNN(ReaxFF):
                 self.diffa[bd]  = tf.reduce_sum(input_tensor=tf.nn.relu(self.bo0[bd]*fao-self.atol))
                 l_atol = tf.add(self.diffa[bd],l_atol)
 
-             fao_= tf.where(tf.less_equal(self.rbd[bd],bm_*self.re[bd]),1.0,0.0) ##### r< 1.2*re that bo > botol
-             diffa_ = tf.reduce_sum(input_tensor=tf.nn.relu(self.botol-self.bo0[bd])*fao_)
-             l_atol = tf.add(diffa_,l_atol)
+             if self.spv_bm:
+                fao_= tf.where(tf.less_equal(self.rbd[bd],bm_*self.re[bd]),1.0,0.0) ##### r< 1.2*re that bo > botol
+                self.diffa[bd] = tf.reduce_sum(input_tensor=tf.nn.relu(self.botol-self.bo0[bd])*fao_)
+                l_atol = tf.add(self.diffa[bd],l_atol)
 
              #  bop should be zero if r>rcut
              fbo = tf.where(tf.less_equal(self.rbd[bd],self.rc_bo[bd]),0.0,1.0) ##### r> rc_bo that bo < botol
-             diffb_  = tf.reduce_sum(self.bop[bd]*fbo)
-             l_atol  = tf.add(diffb_,l_atol)
-
-             fe  = tf.where(tf.less_equal(self.rbd[bd],self.re[bd]),1.0,0.0) ##### r< re that bo > bore_
-             self.diffe[bd]  = tf.reduce_sum(input_tensor=tf.nn.relu((bore_-self.bo0[bd])*fe))
-             l_atol  = tf.add(self.diffe[bd],l_atol)
-             l_atol= tf.add(tf.nn.relu(self.rc_bo[bd]-self.rcut[bd]),l_atol)
+             self.diffb[bd]  = tf.reduce_sum(self.bop[bd]*fbo)
+             l_atol  = tf.add(self.diffb[bd],l_atol)
+             
+             if self.spv_be:
+                fe  = tf.where(tf.less_equal(self.rbd[bd],self.re[bd]),1.0,0.0) ##### r< re that bo > bore_
+                self.diffe[bd]  = tf.reduce_sum(input_tensor=tf.nn.relu((bore_-self.bo0[bd])*fe))
+                l_atol  = tf.add(self.diffe[bd],l_atol)
+                l_atol= tf.add(tf.nn.relu(self.rc_bo[bd]-self.rcut[bd]),l_atol)
       return l_atol*self.bo_penalty
 
   def get_loss(self):
       self.Loss = 0.0
       for mol in self.mols:
           mol_ = mol.split('-')[0]
-          if mol_ in self.weight:
+          if mol in self.weight:
+             w_ = self.weight[mol]
+          elif mol_ in self.weight:
              w_ = self.weight[mol_]
           else:
              w_ = self.weight['others']
+          # print(mol,w_)
 
           if self.losFunc   == 'n2':
              self.loss[mol] = tf.nn.l2_loss(self.E[mol]-self.dft_energy[mol],
@@ -332,22 +341,24 @@ class MPNN(ReaxFF):
       bdr     = b[1]+'-'+b[0]
       flabel  = 'f'+str(t)
       if self.MessageFunction==1:
-         Fi      = self.f_nn(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.bf_layer[1])
-         Fj      = self.f_nn(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.bf_layer[1])
+         Fi      = self.f_nn(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
+         Fj      = self.f_nn(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
          F       = 2.0*Fi*Fj
        
          bosi    = self.Hsi[t-1][bd]*F
          bopi    = self.Hpi[t-1][bd]*F
          bopp    = self.Hpp[t-1][bd]*F
       elif self.MessageFunction==2:
-         Fi      = self.fmassage(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.bf_layer[1])
-         Fj      = self.fmassage(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.bf_layer[1])
+         Fi      = self.fmassage(flabel,bd, self.nbd[bd],[Dbi,Dbj,h],layer=self.mf_layer[1])
+         Fj      = self.fmassage(flabel,bdr,self.nbd[bd],[Dbj,Dbi,h],layer=self.mf_layer[1])
          F       = 2.0*Fi*Fj
          Fsi,Fpi,Fpp = tf.unstack(F,axis=2)
        
          bosi    = self.Hsi[t-1][bd]*Fsi
          bopi    = self.Hpi[t-1][bd]*Fpi
          bopp    = self.Hpp[t-1][bd]*Fpp
+      else:
+         raise NotImplementedError('-  Message function not supported yet!')
       bo      = bosi+bopi+bopp
       return bo,bosi,bopi,bopp
 
@@ -361,7 +372,7 @@ class MPNN(ReaxFF):
       D           = tf.gather_nd(BO,self.dlist)  
       self.Deltap = tf.reduce_sum(input_tensor=D,axis=1,name='Deltap')
 
-      self.massage_passing()
+      self.message_passing()
       self.get_final_sate()
 
       i = 0                           # get bond energy
@@ -377,7 +388,7 @@ class MPNN(ReaxFF):
           self.ebda[mol] = tf.gather_nd(EBDA,self.bdlink[mol])  
           self.ebond[mol]= tf.reduce_sum(input_tensor=self.ebda[mol],axis=0,name='bondenergy')
 
-  def massage_passing(self):
+  def message_passing(self):
       ''' finding the final Bond－order with a massage passing '''
       self.H.append(self.bop)                   # 
       self.Hsi.append(self.bop_si)              #
@@ -496,11 +507,11 @@ class MPNN(ReaxFF):
       self.set_wb(pref='fpp',reuse_m=reuse_m,nin=1,nout=1,layer=self.bo_layer,
                   vlist=self.bonds,nnopt=self.mpopt[0],bias=2.0)
  
-      reuse_m = True if self.bf_layer==self.bf_layer_ else False
+      reuse_m = True if self.mf_layer==self.mf_layer_ else False
       for t in range(1,self.messages+1):
           b = 0.881373587 if t>1 else -0.867
           nout_ = 1 if self.MessageFunction==1 else 3
-          self.set_wb(pref='f'+str(t),reuse_m=reuse_m,nin=3,nout=nout_,layer=self.bf_layer,
+          self.set_wb(pref='f'+str(t),reuse_m=reuse_m,nin=3,nout=nout_,layer=self.mf_layer,
                       vlist=bond,nnopt=self.mpopt[t],bias=b)
 
       if self.EnergyFunction==self.EnergyFunction_ and self.be_layer==self.be_layer_:
@@ -611,7 +622,7 @@ class MPNN(ReaxFF):
               'MessageFunction':self.MessageFunction, 
               'messages':self.messages,
               'bo_layer':self.bo_layer,
-              'bf_layer':self.bf_layer,
+              'mf_layer':self.mf_layer,
               'be_layer':self.be_layer,
               'vdw_layer':self.vdw_layer,
               'MolEnergy':self.MolEnergy_,}
