@@ -17,7 +17,7 @@ from irff.irff_np import IRFF_NP
 from irff.mpnn import MPNN
 
 
-def e(traj='md.traj',efunc=3,fm=2,batch_size=50,nn=True):
+def e(traj='md.traj',efunc=3,fm=1,batch_size=50,nn=True):
     ffield = 'ffield.json' if nn else 'ffield'
     images = Trajectory(traj)
     e = []
@@ -38,8 +38,15 @@ def e(traj='md.traj',efunc=3,fm=2,batch_size=50,nn=True):
         el.append(ir.Elone.numpy())
         eo.append(ir.Eover.numpy())
         eu.append(ir.Eunder.numpy())
-        ea.append(ir.Eang.numpy())
-        ep.append(ir.Epen.numpy())
+        # print(ir.Eang)
+        try:
+           ea.append(ir.Eang.numpy())
+        except:
+           ea.append(ir.Eang)
+        try:
+           ep.append(ir.Epen.numpy())
+        except:
+           ep.append(ir.Epen)
         try:
            et.append(ir.Etor.numpy())
         except:
@@ -48,9 +55,15 @@ def e(traj='md.traj',efunc=3,fm=2,batch_size=50,nn=True):
            ef.append(ir.Efcon.numpy())
         except:
            ef.append(ir.Efcon)
-        etc.append(ir.Etcon.numpy())
+        try:
+           etc.append(ir.Etcon.numpy())
+        except:
+           etc.append(ir.Etcon)
         ev.append(ir.Evdw.numpy())
-        eh.append(ir.Ehb.numpy())
+        try:
+           eh.append(ir.Ehb.numpy())
+        except:
+           eh.append(ir.Ehb)
         ec.append(ir.Ecoul.numpy())
 
     rn = MPNN(libfile=ffield,
@@ -58,14 +71,14 @@ def e(traj='md.traj',efunc=3,fm=2,batch_size=50,nn=True):
               dft='siesta',
               opt=[],optword='nocoul',
               batch_size=batch_size,
-              atomic=True,
               clip_op=False,
               InitCheck=False,
               nn=nn,
-              bo_layer=[9,3],
+              bo_layer=[4,1],
+              bf_layer=[6,2],
+              be_layer=[3,1],
               EnergyFunction=efunc,
-              MessageFunction=fm,
-              pkl=False) 
+              MessageFunction=fm) 
     molecules = rn.initialize()
     rn.session(learning_rate=1.0e-10,method='AdamOptimizer')
 
@@ -84,6 +97,13 @@ def e(traj='md.traj',efunc=3,fm=2,batch_size=50,nn=True):
     ec_  = rn.get_value(rn.ecoul[mol])
     eh_  = rn.get_value(rn.ehb[mol])
 
+    db_  = rn.get_value(rn.diffb)
+    da_  = rn.get_value(rn.diffa)
+    de_  = rn.get_value(rn.diffe)
+
+    for bd in db_:
+        print(bd,db_[bd],da_[bd],de_[bd])
+
     e_irff = {'Energy':e,'Ebond':eb,'Eunger':eu,'Eover':eo,'Eang':ea,'Epen':ep,
               'Elone':el,
               'Etcon':etc,'Etor':et,'Efcon':ef,'Evdw':ev,'Ecoul':ec,'Ehbond':eh}
@@ -96,16 +116,16 @@ def e(traj='md.traj',efunc=3,fm=2,batch_size=50,nn=True):
         plt.ylabel('%s (eV)' %key)
         plt.xlabel('Step')
 
-        plt.plot(e_reax[key],alpha=0.01,
+        plt.plot(e_reax[key],alpha=0.6,
                  linestyle='-.',marker='o',markerfacecolor='none',
                  markeredgewidth=1,markeredgecolor='b',markersize=4,
                  color='blue',label='ReaxFF')
-        plt.plot(e_irff[key],alpha=0.01,
+        plt.plot(e_irff[key],alpha=0.6,
                  linestyle=':',marker='^',markerfacecolor='none',
                  markeredgewidth=1,markeredgecolor='red',markersize=4,
                  color='red',label='IRFF')
         plt.legend(loc='best',edgecolor='yellowgreen') # lower left upper right
-        plt.savefig('%s.eps' %key) 
+        plt.savefig('%s.pdf' %key) 
         plt.close() 
 
 
@@ -699,4 +719,4 @@ if __name__ == '__main__':
    argh.add_commands(parser, [e,ep,db,dl,da,dt,dh,dr])
    argh.dispatch(parser)  
 
-   
\ No newline at end of file
+   
